package org.jeecg.modules.app.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.log4j.Log4j2;
import org.jeecg.modules.app.service.IDetailService;
import org.jeecg.modules.app.vo.PlaceInfoVO;
import org.jeecg.modules.system.app.entity.AppInstructor;
import org.jeecg.modules.system.app.entity.AppOrderProduct;
import org.jeecg.modules.system.app.entity.AppSite;
import org.jeecg.modules.system.app.entity.AppSitePriceRules;
import org.jeecg.modules.system.app.mapper.*;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
@Service
@Log4j2
public class DetailServiceImpl implements IDetailService {
    @Resource
    private AppSiteMapper appSiteMapper;
    @Resource
    private AppCoursesPriceRulesMapper appCoursesPriceRulesMapper;
    @Resource
    private AppOrderProductMapper appOrderProductMapper;
    @Resource
    private AppSitePriceRulesMapper appSitePriceRulesMapper;
    @Resource
    private AppInstructorMapper appInstructorMapper;

    @Override
    public PlaceInfoVO getPlaceInfo(String id) {
        AppSite appSite = appSiteMapper.selectById(id);
        PlaceInfoVO placeInfo = appSiteMapper.getPlaceInfo(id);
        List<PlaceInfoVO.InstructorVO> instructorVOList = new ArrayList<>();
        List<AppInstructor> appInstructors = appInstructorMapper.selectList(Wrappers.<AppInstructor>lambdaQuery()
                .eq(AppInstructor::getOrgCode, appSite.getOrgCode()));
        if (appInstructors != null) {
            for (AppInstructor instructor : appInstructors) {
                PlaceInfoVO.InstructorVO vo = new PlaceInfoVO.InstructorVO();
                BeanUtils.copyProperties(vo, instructor); // 注意参数顺序
                instructorVOList.add(vo);
            }
        }
        AppSitePriceRules appSitePriceRules = appSitePriceRulesMapper.selectOne(Wrappers.<AppSitePriceRules>lambdaQuery()
                .eq(AppSitePriceRules::getSiteId, id)
                .eq(AppSitePriceRules::getStatus, 0)
                .last("limit 1"));
        PlaceInfoVO.PlaceInfoMsgVO placeInfoMsgVO = new PlaceInfoVO.PlaceInfoMsgVO();
        placeInfoMsgVO.setName(appSite.getName())
                .setSales(getPlaceSales(id))
                .setOriginalPrice(appSitePriceRules.getOriginalPrice())
                .setSellingPrice(appSitePriceRules.getSellingPrice());
        placeInfo.setInstructorVOList(instructorVOList)
                .setPlaceInfoMsgVO(placeInfoMsgVO);
        //todo 评价查询待添加
        return placeInfo;
    }

    /**
     * @return
     * @Author SheepHy
     * @Description 查询门店下场地销售次数
     * @Date 20:02 2025/7/7
     * @Param
     **/
    public int getPlaceSales(String id) {
        List<String> ids = appCoursesPriceRulesMapper.selectRuleIdsByCourseId(id);
        int totalOrders = 0;
        if (!ids.isEmpty()) {
            totalOrders = Math.toIntExact(appOrderProductMapper.selectCount(
                    Wrappers.<AppOrderProduct>lambdaQuery()
                            .in(AppOrderProduct::getProductId, ids)
            ));
        }
        return totalOrders;
    }
}