package org.jeecg.modules.system.app.controller;

import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.system.app.dto.AppSiteDTO;
import org.jeecg.modules.system.app.dto.AppSitePageDTO;
import org.jeecg.modules.system.app.entity.AppSite;
import org.jeecg.modules.system.app.entity.AppSitePriceRules;
import org.jeecg.modules.system.app.service.IAppSitePriceRulesService;
import org.jeecg.modules.system.app.service.IAppSiteService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;



/**
 * @Description: 场地表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Tag(name="场地表")
@RestController
@RequestMapping("/appSite")
@Slf4j
public class AppSiteController extends JeecgController<AppSite, IAppSiteService> {
	@Autowired
	private IAppSiteService appSiteService;
	@Autowired
	private IAppSitePriceRulesService sitePriceRulesService;

	/**
	 * 分页列表查询
	 *
	 * @param dto
	 * @return
	 */
	//@AutoLog(value = "场地表-分页列表查询")
	@Operation(summary="场地表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppSiteDTO>> queryPageList(AppSitePageDTO dto) {
		return Result.OK(appSiteService.querySiteList(dto));
	}

	/**
	 *   添加
	 *
	 * @param appSiteDTO
	 * @return
	 */
	@AutoLog(value = "场地表-添加")
	@Operation(summary="场地表-添加")
//	@RequiresPermissions("org.jeecg.modules.app:nm_site:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppSiteDTO appSiteDTO) {
		return appSiteService.saveWitchPriceRules(appSiteDTO)?Result.OK("添加成功！"):Result.error("添加失败！");
	}

	/**
	 *  编辑
	 *
	 * @param appSiteDTO
	 * @return
	 */
	@AutoLog(value = "场地表-编辑")
	@Operation(summary="场地表-编辑")
//	@RequiresPermissions("org.jeecg.modules.app:nm_site:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppSiteDTO appSiteDTO) {
		return appSiteService.editWitchPriceRules(appSiteDTO)?Result.OK("操作成功！"):Result.error("操作失败！");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "场地表-通过id删除")
	@Operation(summary="场地表-通过id删除")
//	@RequiresPermissions("org.jeecg.modules.app:nm_site:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {

		return appSiteService.deleteWitchPriceRulesById(id)? Result.OK("删除成功!"):Result.error("删除失败！");
	}

//	/**
//	 *  批量删除
//	 *
//	 * @param ids
//	 * @return
//	 */
//	@AutoLog(value = "场地表-批量删除")
//	@Operation(summary="场地表-批量删除")
//	@RequiresPermissions("org.jeecg.modules.app:nm_site:deleteBatch")
//	@DeleteMapping(value = "/deleteBatch")
//	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
//		this.appSiteService.removeByIds(Arrays.asList(ids.split(",")));
//		return Result.OK("批量删除成功!");
//	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "场地表-通过id查询")
	@Operation(summary="场地表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppSiteDTO> queryById(@RequestParam(name="id",required=true) String id) {
			return Result.ok(appSiteService.queryWitchPriceRulesById(id));
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appSite
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppSite appSite) {
        return super.exportXls(request, appSite, AppSite.class, "场地表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppSite.class);
    }

}
