package org.jeecg.modules.system.app.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * @Description: 赛事表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Data
@TableName("nm_game")
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@Schema(description="赛事表")
public class AppGame implements Serializable {
    private static final long serialVersionUID = 1L;

	/**id*/
	@TableId(type = IdType.ASSIGN_ID)
    @Schema(description = "id")
    private String id;
	/**部门id*/
	@Excel(name = "部门id", width = 15)
    @Schema(description = "部门id")
    private String orgCode;
	/**商户/场地id;场馆/主办单位/学校等场地*/
	@Excel(name = "商户/场地id;场馆/主办单位/学校等场地", width = 15)
    @Schema(description = "商户/场地id;场馆/主办单位/学校等场地")
    private String tenantId;
	/**产品名称*/
	@Excel(name = "产品名称", width = 15)
    @Schema(description = "产品名称")
    private String name;
	/**举办方*/
	@Excel(name = "举办方", width = 15)
    @Schema(description = "举办方")
    private String organizers;
	/**举办地址*/
	@Excel(name = "举办地址", width = 15)
    @Schema(description = "举办地址")
    private String address;
	/**类型;0单人 1团队*/
	@Excel(name = "类型;0单人 1团队", width = 15)
    @Schema(description = "类型;0单人 1团队")
    private Integer type;
	/**保险id;可能有多个险种*/
	@Excel(name = "保险id;可能有多个险种", width = 15)
    @Schema(description = "保险id;可能有多个险种")
    private String insureIds;
	/**封面*/
	@Excel(name = "封面", width = 15)
    @Schema(description = "封面")
    private String cover;
	/**背景图;可能数组*/
	@Excel(name = "背景图;可能数组", width = 15)
    @Schema(description = "背景图;可能数组")
    private String backgroundImage;
	/**退款类型;0可退/到期自动退 1限时退 2不可退*/
	@Excel(name = "退款类型;0可退/到期自动退 1限时退 2不可退", width = 15)
    @Schema(description = "退款类型;0可退/到期自动退 1限时退 2不可退")
    private Integer refundType;
	/**有效期;单位：天 仅无固定场*/
	@Excel(name = "有效期;单位：天 仅无固定场", width = 15)
    @Schema(description = "有效期;单位：天 仅无固定场")
    private Integer indate;
	/**提前预约时间;单位：时 0面预约*/
	@Excel(name = "提前预约时间;单位：时 0面预约", width = 15)
    @Schema(description = "提前预约时间;单位：时 0面预约")
    private Integer advanceTime;
	/**适用人数*/
	@Excel(name = "适用人数", width = 15)
    @Schema(description = "适用人数")
    private Integer usableCount;
	/**提示/须知*/
	@Excel(name = "提示/须知", width = 15)
    @Schema(description = "提示/须知")
    private String reminder;
	/**视频*/
	@Excel(name = "视频", width = 15)
    @Schema(description = "视频")
    private String video;
	/**开始时间*/
	@Excel(name = "开始时间", width = 20, format = "yyyy-MM-dd HH:mm:ss")
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "开始时间")
    private Date startTime;
	/**结束时间*/
	@Excel(name = "结束时间", width = 20, format = "yyyy-MM-dd HH:mm:ss")
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "结束时间")
    private Date endTime;
    /**报名截止时间*/
    @Excel(name = "报名截止时间", width = 20, format = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "报名截止时间")
    private Date applicationEndTime;
	/**排序*/
	@Excel(name = "排序", width = 15)
    @Schema(description = "排序")
    private Integer sort;
	/**系统状态;状态（0-正常,1-冻结）*/
	@Excel(name = "系统状态;状态（0-正常,1-冻结）", width = 15)
    @Schema(description = "系统状态;状态（0-正常,1-冻结）")
    private Integer status;
	/**删除标志;删除状态(0-正常,1-已删除)*/
	@Excel(name = "删除标志;删除状态(0-正常,1-已删除)", width = 15)
    @Schema(description = "删除标志;删除状态(0-正常,1-已删除)")
    @TableLogic
    private Integer delFlag;
	/**乐观锁*/
	@Excel(name = "乐观锁", width = 15)
    @Schema(description = "乐观锁")
    private Integer revision;
	/**创建人;创建人*/
    @Schema(description = "创建人;创建人")
    private String createBy;
	/**创建时间;创建时间*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间;创建时间")
    private Date createTime;
	/**更新人;更新人*/
    @Schema(description = "更新人;更新人")
    private String updateBy;
	/**更新时间;更新时间*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间;更新时间")
    private Date updateTime;
}
